@@ -2,4 +2,7 @@ package org.af.gMCP.gui.graph.annotations;
 
 public class Ellipse {
 
+	public Ellipse() {
+		
+	}
 }
